@@ -883,10 +883,6 @@ p, li { white-space: pre-wrap; }
         <source>Import directory</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Online Help</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Open online help</source>
         <translation type="unfinished"></translation>
@@ -907,6 +903,10 @@ p, li { white-space: pre-wrap; }
         <source>Donate via Paypal, Ko-Fi, Cryptocurrencies</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Online Help</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindowImpl</name>
