@@ -893,10 +893,6 @@ p, li { white-space: pre-wrap; }
         <source>Import directory</source>
         <translation>İçe aktarma dizini</translation>
     </message>
-    <message>
-        <source>Online Help</source>
-        <translation>Çevrim İçi Yardım</translation>
-    </message>
     <message>
         <source>Open online help</source>
         <translation>Çevrim içi yardımı aç</translation>
@@ -917,6 +913,10 @@ p, li { white-space: pre-wrap; }
         <source>Donate via Paypal, Ko-Fi, Cryptocurrencies</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>&amp;Online Help</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MainWindowImpl</name>
